@@ -1,7 +1,7 @@
 from .dialog import Dialog
 from .manager.protocols import DialogManager
 from .manager.registry import DialogRegistry
-from .manager.bg_manager import BgManager
+from .manager.bg_manager import BgManagerProto as BgManager
 from .window import Window
 from .manager.intent import ChatEvent
 
